@@ -37,25 +37,11 @@ from cproton import PN_ARRAY, PN_BINARY, PN_BOOL, PN_BYTE, PN_CHAR, PN_DECIMAL12
     pn_data_put_string, pn_data_put_symbol, pn_data_put_timestamp, pn_data_put_ubyte, pn_data_put_uint, \
     pn_data_put_ulong, pn_data_put_ushort, pn_data_put_uuid, pn_data_rewind, pn_data_type, pn_data_widen, pn_error_text
 
-from . import _compat
 from ._common import Constant
 from ._exceptions import DataException, EXCEPTIONS
 
-#
-# Hacks to provide Python2 <---> Python3 compatibility
-#
-# The results are
-# |       |long|unicode|
-# |Python2|long|unicode|
-# |Python3| int|    str|
-try:
-    long()
-except NameError:
-    long = int
-try:
-    unicode()
-except NameError:
-    unicode = str
+long = int
+unicode = str
 
 
 class UnmappedType:
@@ -70,7 +56,7 @@ class UnmappedType:
 class ulong(long):
     """
     The ulong AMQP type.
-    
+
     An unsigned 64 bit integer in the range :math:`0` to :math:`2^{64} - 1` inclusive.
     """
 
@@ -86,7 +72,7 @@ class ulong(long):
 class timestamp(long):
     """
     The timestamp AMQP type.
-    
+
     An absolute point in time, represented by a signed 64 bit value measuring
     milliseconds since the epoch. This value is encoded using the Unix ``time_t``
     [IEEE1003] encoding of UTC, but with a precision of milliseconds. For
@@ -100,7 +86,7 @@ class timestamp(long):
 class symbol(unicode):
     """
     The symbol AMQP type.
-    
+
     Symbolic values from a constrained domain, represented by a sequence of ASCII characters.
     """
 
@@ -111,7 +97,7 @@ class symbol(unicode):
 class char(unicode):
     """
     The char AMQP type.
-    
+
     A 32 bit UTF-32BE encoded Unicode character.
     """
 
@@ -122,7 +108,7 @@ class char(unicode):
 class byte(int):
     """
     The byte AMQP type.
-    
+
     An 8 bit signed integer in the range :math:`-(2^7)` to :math:`2^7 - 1` inclusive.
     """
 
@@ -133,7 +119,7 @@ class byte(int):
 class short(int):
     """
     The short AMQP type.
-    
+
     A 16 bit signed integer in the range :math:`-(2^{15})` to :math:`2^{15} - 1` inclusive.
     """
 
@@ -144,7 +130,7 @@ class short(int):
 class int32(int):
     """
     The signed int AMQP type.
-    
+
     A 32 bit signed integer in the range :math:`-(2^{31})` to :math:`2^{31} - 1` inclusive.
     """
 
@@ -155,7 +141,7 @@ class int32(int):
 class ubyte(int):
     """
     The unsigned byte AMQP type.
-    
+
     An 8 bit unsigned integer in the range :math:`0` to :math:`2^8 - 1` inclusive.
     """
 
@@ -171,7 +157,7 @@ class ubyte(int):
 class ushort(int):
     """
     The unsigned short AMQP type.
-    
+
     A 16 bit unsigned integer in the range :math:`0` to :math:`2^{16} - 1` inclusive.
     """
 
@@ -187,7 +173,7 @@ class ushort(int):
 class uint(long):
     """
     The unsigned int AMQP type.
-    
+
     A 32 bit unsigned integer in the range :math:`0` to :math:`2^{32} - 1` inclusive.
     """
 
@@ -203,7 +189,7 @@ class uint(long):
 class float32(float):
     """
     The float AMQP type.
-    
+
     A 32 bit floating point number (IEEE 754-2008 binary32).
     """
 
@@ -214,7 +200,7 @@ class float32(float):
 class decimal32(int):
     """
     The decimal32 AMQP type.
-    
+
     A 32 bit decimal floating point  number (IEEE 754-2008 decimal32).
     """
 
@@ -225,7 +211,7 @@ class decimal32(int):
 class decimal64(long):
     """
     The decimal64 AMQP type.
-    
+
     A 64 bit decimal floating point number (IEEE 754-2008 decimal64).
     """
 
@@ -236,7 +222,7 @@ class decimal64(long):
 class decimal128(bytes):
     """
     The decimal128 AMQP type.
-    
+
     A 128-bit decimal floating-point number (IEEE 754-2008 decimal128).
     """
 
@@ -282,7 +268,7 @@ class Array(object):
     :ivar type: Array element type, as an integer. The :class:`Data` class has constants defined
         for all the valid AMQP types. For example, for an array of double values, use
         :const:`Data.DOUBLE`, which has integer value 14.
-    :ivar elements: A Python list of elements of the appropriate type.    
+    :ivar elements: A Python list of elements of the appropriate type.
     """
 
     def __init__(self, descriptor, type, *elements):
@@ -303,7 +289,7 @@ class Array(object):
     def __eq__(self, o):
         if isinstance(o, Array):
             return self.descriptor == o.descriptor and \
-                   self.type == o.type and self.elements == o.elements
+                self.type == o.type and self.elements == o.elements
         else:
             return False
 
@@ -334,6 +320,7 @@ def _check_is_symbol_or_ulong(s, raise_on_error=True):
 
 class RestrictedKeyDict(dict):
     """Parent class for :class:`PropertyDict` and :class:`AnnotationDict`"""
+
     def __init__(self, validation_fn, e=None, raise_on_error=True, **kwargs):
         super(RestrictedKeyDict, self).__init__()
         self.validation_fn = validation_fn
@@ -401,6 +388,7 @@ class PropertyDict(RestrictedKeyDict):
     :type raise_on_error: ``bool``
     :param kwargs: Keyword args for initializing a ``dict`` of the form key1=val1, key2=val2, ...
     """
+
     def __init__(self, e=None, raise_on_error=True, **kwargs):
         super(PropertyDict, self).__init__(_check_is_symbol, e, raise_on_error, **kwargs)
 
@@ -445,6 +433,7 @@ class AnnotationDict(RestrictedKeyDict):
     :type raise_on_error: ``bool``
     :param kwargs: Keyword args for initializing a ``dict`` of the form key1=val1, key2=val2, ...
     """
+
     def __init__(self, e=None, raise_on_error=True, **kwargs):
         super(AnnotationDict, self).__init__(_check_is_symbol_or_ulong, e, raise_on_error, **kwargs)
 
@@ -483,6 +472,7 @@ class SymbolList(list):
         an error.
     :type raise_on_error: ``bool``
     """
+
     def __init__(self, t=None, raise_on_error=True):
         super(SymbolList, self).__init__()
         self.raise_on_error = raise_on_error
@@ -578,31 +568,31 @@ class Data:
         * :const:`MAP`
     """
 
-    NULL = PN_NULL; "A null value."
-    BOOL = PN_BOOL; "A boolean value."
-    UBYTE = PN_UBYTE; "An unsigned byte value."
-    BYTE = PN_BYTE; "A signed byte value."
-    USHORT = PN_USHORT; "An unsigned short value."
-    SHORT = PN_SHORT; "A short value."
-    UINT = PN_UINT; "An unsigned int value."
-    INT = PN_INT; "A signed int value."
-    CHAR = PN_CHAR; "A character value."
-    ULONG = PN_ULONG; "An unsigned long value."
-    LONG = PN_LONG; "A signed long value."
-    TIMESTAMP = PN_TIMESTAMP; "A timestamp value."
-    FLOAT = PN_FLOAT; "A float value."
-    DOUBLE = PN_DOUBLE; "A double value."
-    DECIMAL32 = PN_DECIMAL32; "A DECIMAL32 value."
-    DECIMAL64 = PN_DECIMAL64; "A DECIMAL64 value."
-    DECIMAL128 = PN_DECIMAL128; "A DECIMAL128 value."
-    UUID = PN_UUID; "A UUID value."
-    BINARY = PN_BINARY; "A binary string."
-    STRING = PN_STRING; "A unicode string."
-    SYMBOL = PN_SYMBOL; "A symbolic string."
-    DESCRIBED = PN_DESCRIBED; "A described value."
-    ARRAY = PN_ARRAY; "An array value."
-    LIST = PN_LIST; "A list value."
-    MAP = PN_MAP; "A map value."
+    NULL = PN_NULL  #: A null value.
+    BOOL = PN_BOOL  #: A boolean value.
+    UBYTE = PN_UBYTE  #: An unsigned byte value.
+    BYTE = PN_BYTE  #: A signed byte value.
+    USHORT = PN_USHORT  #: An unsigned short value.
+    SHORT = PN_SHORT  #: A short value.
+    UINT = PN_UINT  #: An unsigned int value.
+    INT = PN_INT  #: A signed int value.
+    CHAR = PN_CHAR  #: A character value.
+    ULONG = PN_ULONG  #: An unsigned long value.
+    LONG = PN_LONG  #: A signed long value.
+    TIMESTAMP = PN_TIMESTAMP  #: A timestamp value.
+    FLOAT = PN_FLOAT  #: A float value.
+    DOUBLE = PN_DOUBLE  #: A double value.
+    DECIMAL32 = PN_DECIMAL32  #: A DECIMAL32 value.
+    DECIMAL64 = PN_DECIMAL64  #: A DECIMAL64 value.
+    DECIMAL128 = PN_DECIMAL128  #: A DECIMAL128 value.
+    UUID = PN_UUID  #: A UUID value.
+    BINARY = PN_BINARY  #: A binary string.
+    STRING = PN_STRING  #: A unicode string.
+    SYMBOL = PN_SYMBOL  #: A symbolic string.
+    DESCRIBED = PN_DESCRIBED  #: A described value.
+    ARRAY = PN_ARRAY  #: An array value.
+    LIST = PN_LIST  #: A list value.
+    MAP = PN_MAP  #: A map value.
 
     type_names = {
         NULL: "null",
@@ -639,9 +629,9 @@ class Data:
     def type_name(amqptype):
         """
         Return a string name for an AMQP type.
-        
-        :param type: Numeric Proton AMQP type (`enum pn_type_t`)
-        :type type: integer
+
+        :param amqptype: Numeric Proton AMQP type (`enum pn_type_t`)
+        :type amqptype: integer
         :rtype: String describing the AMQP type with numeric value `amqptype`
         """
         return Data.type_names[amqptype]
@@ -954,7 +944,7 @@ class Data:
 
         :param ui: an integral value in the range :math:`0` to :math:`2^{32} - 1` inclusive.
         :type ui: ``int``, :class:`uint`
-        :raise: * ``AssertionError`` if parameter is out of the range :math:`0` to :math:`2^{32} - 1` inclusive. 
+        :raise: * ``AssertionError`` if parameter is out of the range :math:`0` to :math:`2^{32} - 1` inclusive.
                 * :exc:`DataException` if there is a Proton error.
         """
         self._check(pn_data_put_uint(self._data, ui))
@@ -996,7 +986,7 @@ class Data:
         Puts a signed long value.
 
         :param l: an integral value in the range :math:`-(2^{63})` to :math:`2^{63} - 1` inclusive.
-        :type ul: ``int``, ``long``
+        :type l: ``int``, ``long``
         :raise: * ``AssertionError`` if parameter is out of the range :math:`-(2^{63})` to :math:`2^{63} - 1` inclusive.
                 * :exc:`DataException` if there is a Proton error.
         """
@@ -1183,7 +1173,7 @@ class Data:
             >>> data.exit()
 
         :return: A tuple containing the number of array elements, the descriptor
-            (or ``None`` if no descriptor) and the enumerated array element type. 
+            (or ``None`` if no descriptor) and the enumerated array element type.
         :rtype: ``tuple`` (``int``, ``str`` or ``None``, ``int``)
         """
         count = pn_data_get_array(self._data)
@@ -1292,7 +1282,7 @@ class Data:
         :return: If the current node is a char, its value, 0 otherwise.
         :rtype: :class:`char`
         """
-        return char(_compat.unichr(pn_data_get_char(self._data)))
+        return char(chr(pn_data_get_char(self._data)))
 
     def get_ulong(self):
         """
@@ -1412,7 +1402,7 @@ class Data:
         """
         Copy the contents of another pn_data_t object. Any values in the
         data object will be lost.
-        
+
         :param src: The source object from which to copy
         :type src: :class:`Data`
         :raise: :exc:`DataException` if there is a Proton error.
@@ -1566,7 +1556,8 @@ class Data:
         """
 
         count, described, type = self.get_array()
-        if type is None: return None
+        if type is None:
+            return None
         if self.enter():
             try:
                 if described:
@@ -1631,21 +1622,9 @@ class Data:
         Array: put_py_array,
         AnnotationDict: put_dict,
         PropertyDict: put_dict,
-        SymbolList: put_sequence
+        SymbolList: put_sequence,
+        memoryview: put_memoryview
     }
-    # for Python 3.x, long is merely an alias for int, but for Python 2.x
-    # we need to add an explicit int since it is a different type
-    if int not in put_mappings:
-        put_mappings[int] = put_int
-    # Python >=3.0 has 'memoryview', <=2.5 has 'buffer', >=2.6 has both.
-    try:
-        put_mappings[memoryview] = put_memoryview
-    except NameError:
-        pass
-    try:
-        put_mappings[buffer] = put_buffer
-    except NameError:
-        pass
     get_mappings = {
         NULL: lambda s: None,
         BOOL: get_bool,
@@ -1680,7 +1659,8 @@ class Data:
 
     def get_object(self):
         type = self.type()
-        if type is None: return None
+        if type is None:
+            return None
         getter = self.get_mappings.get(type)
         if getter:
             return getter(self)
